Type: Package
Package: saros
Title: Semi-Automatic Reporting of Ordinary Surveys
Version: 1.6.2
Authors@R: c(
    person(given = "Stephan", 
           family = "Daus", 
           role = c("aut", "cre", "cph"),
           email = "stephus.daus@gmail.com", 
           comment = c(ORCID = "0000-0003-0230-6997")),
    person("Julia", "Silge", role = c("ctb"), comment = "Author of internal scale_x_reordered"),
    person("David", "Robinson", role = c("ctb"), comment = "Author of internal scale_x_reordered"),
    person("Nordic Institute for The Studies of Innovation, Research and Education (NIFU)", 
           role = c("fnd")),
    person("Kristiania University College", 
           role = c("fnd"))
  )
Maintainer: Stephan Daus <stephus.daus@gmail.com>
Description: Offers a systematic way for conditional reporting of figures and tables for many
    (and bivariate combinations of) variables, typically from survey data.
    Contains interactive 'ggiraph'-based 
    (<https://CRAN.R-project.org/package=ggiraph>) plotting functions and
    data frame-based summary tables (bivariate significance tests, 
    frequencies/proportions, unique open ended responses, etc) with
    many arguments for customization, and extensions possible. Uses a global 
    options() system for neatly reducing redundant code.
    Also contains tools for immediate saving of objects and returning a hashed link to the object,
    useful for creating download links to high resolution images upon rendering in 'Quarto'. 
    Suitable for highly customized reports, primarily intended for survey
    research.
Note: Free to use for non-Norwegian institutions, otherwise see
        LICENSE.
License: MIT + file LICENSE
URL: https://nifu-no.github.io/saros/, https://github.com/NIFU-NO/saros
BugReports: https://github.com/NIFU-NO/saros/issues
Depends: R (>= 4.2.0)
Imports: cli, dplyr, forcats, fs, ggiraph, ggplot2, glue, grDevices,
        mschart, officer, rlang, stringi, stats, tidyr, tidyselect,
        utils, vctrs
Suggests: covr, haven, labelled, pdftools, quarto, knitr, readr,
        scales, spelling, srvyr, survey, testthat (>= 3.0.0), tibble,
        vdiffr, withr, writexl, readxl
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3
Language: en-US
VignetteBuilder: quarto
Config/Needs/website: rmarkdown
Config/testthat/parallel: true
LazyData: true
NeedsCompilation: no
Packaged: 2026-04-29 23:18:22 UTC; py128
Author: Stephan Daus [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0003-0230-6997>),
  Julia Silge [ctb] (Author of internal scale_x_reordered),
  David Robinson [ctb] (Author of internal scale_x_reordered),
  Nordic Institute for The Studies of Innovation, Research and Education
    (NIFU) [fnd],
  Kristiania University College [fnd]
Repository: CRAN
Date/Publication: 2026-04-29 23:40:02 UTC
Built: R 4.4.3; ; 2026-05-01 15:00:33 UTC; unix
