# Generated by roxygen2: do not edit by hand

S3method(crosstable,data.frame)
S3method(crosstable,tbl_df)
S3method(crosstable,tbl_svy)
S3method(make_content,cat_plot_docx)
S3method(make_content,cat_plot_html)
S3method(make_content,cat_table_docx)
S3method(make_content,cat_table_html)
S3method(make_content,chr_table_docx)
S3method(make_content,chr_table_html)
S3method(make_content,default)
S3method(make_content,int_plot_html)
S3method(make_content,int_table_html)
S3method(make_content,sigtest_table_html)
S3method(make_link,default)
S3method(make_link,list)
S3method(print,saros_officer_plots)
export(check_quarto_website_index)
export(crowd_output)
export(crowd_plots_as_docx)
export(crowd_plots_as_officer)
export(crowd_plots_as_tabset)
export(crowd_tables_as_tabset)
export(fig_height_h_barchart)
export(fig_height_h_barchart2)
export(fig_height_h_barchart2.default)
export(fig_height_h_barchart2.ggplot)
export(fig_height_h_barchart2.ms_chart)
export(get_data_label_opts)
export(get_dep_label_prefix)
export(get_fig_title_suffix_from_ggplot)
export(get_makeme_types)
export(ggsaver)
export(girafe)
export(global_settings_get)
export(global_settings_reset)
export(global_settings_set)
export(insert_text)
export(is_rendering)
export(make_content)
export(make_file_links)
export(make_link)
export(makeme)
export(n_range)
export(n_range2)
export(n_range2.default)
export(n_range2.ggplot)
export(n_range2.ms_chart)
export(output_format)
export(quarto_pdf_post_render)
export(txt_from_cat_mesos_plots)
importFrom(rlang,"!!!")
importFrom(rlang,"%||%")
