% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/checks.R
\name{validate_bool_rule}
\alias{validate_bool_rule}
\title{Create boolean validation rule}
\usage{
validate_bool_rule()
}
\description{
Create boolean validation rule
}
\keyword{internal}
