% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_file_links.R
\name{extract_docx_title}
\alias{extract_docx_title}
\title{Extract Title from DOCX File}
\usage{
extract_docx_title(filepath)
}
\arguments{
\item{filepath}{Path to DOCX file}
}
\value{
Character string with title or NULL
}
\description{
Extract Title from DOCX File
}
\keyword{internal}
