% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_file_links.R
\name{escape_markdown}
\alias{escape_markdown}
\title{Escape Markdown Special Characters}
\usage{
escape_markdown(text)
}
\arguments{
\item{text}{Character string to escape}
}
\value{
Escaped character string safe for markdown link text
}
\description{
Escape Markdown Special Characters
}
\keyword{internal}
