% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_file_links.R
\name{escape_markdown_link}
\alias{escape_markdown_link}
\title{Escape Markdown Link Path}
\usage{
escape_markdown_link(path)
}
\arguments{
\item{path}{Character string path to escape}
}
\value{
Escaped path safe for markdown link URLs
}
\description{
Escape Markdown Link Path
}
\keyword{internal}
